@@ -21,8 +21,13 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from .response import QueryResult as QueryResult
+from .models import QueryResult as QueryResult
 from .sync import Client as Client
-from ._async import AsyncClient as AsyncClient
+from .sync import query as query
 
-__version__ = "0.1.0"
+try:
+    from ._async import AsyncClient as AsyncClient
+except ValueError:  # raised by _async when aiohttp is not present
+    pass
+
+__version__ = "0.2.1"
